@@ -1,9 +1,9 @@
 #' Build and check a package, cleaning up automatically on success.
 #'
 #' \code{check} automatically builds a package before using \code{R CMD check}
-#' as this is the recommended way to check pakcages.  Note that this process
+#' as this is the recommended way to check packages.  Note that this process
 #' runs in an independent realisation of R, so nothing in your current 
-#' workspace will affect the proces.
+#' workspace will affect the process.
 #'
 #' @param pkg package description, can be path or package name.  See
 #'   \code{\link{as.package}} for more information
@@ -12,8 +12,12 @@
 #' @param cleanup if \code{TRUE} the check directory is removed if the check
 #'   is successful - this allows you to inspect the results to figure out what
 #'   went wrong. If \code{FALSE} the check directory is never removed.
+#' @param cran if \code{TRUE} (the default), check with CRAN.
+#' @param args An optional character vector of additional command line
+#'   arguments to be passed to \code{R CMD check}.
 #' @export
-check <- function(pkg = NULL, document = TRUE, cleanup = TRUE) {
+check <- function(pkg = NULL, document = TRUE, cleanup = TRUE,
+  cran = TRUE, args = NULL) {
   pkg <- as.package(pkg)
   
   if (document) {
@@ -23,8 +27,13 @@ check <- function(pkg = NULL, document = TRUE, cleanup = TRUE) {
 
   built_path <- build(pkg, tempdir())  
   on.exit(unlink(built_path))
+
+  opts <- "--timings"
+  if (cran)
+    opts <- c(opts, "--as-cran")
+  opts <- paste(paste(opts, collapse = " "), paste(args, collapse = " "))
   
-  R(paste("CMD check ", built_path, " --timings", sep = ""), tempdir())
+  R(paste("CMD check ", shQuote(built_path), " ", opts, sep = ""), tempdir())
   
   check_path <- file.path(tempdir(), paste(pkg$package, ".Rcheck", 
     sep = ""))
@@ -38,34 +47,3 @@ check <- function(pkg = NULL, document = TRUE, cleanup = TRUE) {
 }
 
 
-#' Check a package from CRAN.
-#'
-#' This is useful for automatically checking that dependencies of your 
-#' packages work.
-#'
-#' The downloaded package and check directory are only removed if the check is
-#' successful - this allows you to inspect the results to figure out what
-#' went wrong.
-#'
-#' @param pkg Package name - note that unlike other \pkg{devtools} functions
-#'   this is the name of a CRAN package, not a path.
-#' @param ... other parameters passed onto \code{\link{download.packages}}
-#' @export
-check_cran <- function(pkg, ...) {
-  message("Checking CRAN package ", pkg)
-
-  tmp <- tempdir()
-  stopifnot(is.character(pkg) && length(pkg) == 1)
-  
-  downloaded <- download.packages(pkg, tmp, type = "source", quiet = TRUE,
-    ...)
-  out_path <- downloaded[1,2]
-  check_path <- gsub("_.*?$", ".Rcheck", out_path)
-  
-  R(paste("CMD check ", out_path, sep = ""), tempdir())
-
-  unlink(out_path)
-  unlink(check_path, recursive = TRUE)
-  
-  invisible(TRUE)
-}
