@@ -6,14 +6,15 @@
 #' @param username Github username
 #' @param repo Repo name
 #' @param branch Desired branch - defaults to \code{"master"}
-#' @param ... Other arguments passed on to \code{\link{install.packages}}.
+#' @param subdir subdirectory within repo that contains the R package.
+#' @param ... Other arguments passed on to \code{\link{install}}.
 #' @export
 #' @family package installation
 #' @examples
 #' \dontrun{
 #' install_github("roxygen")
 #' }
-install_github <- function(repo, username = "hadley", branch = "master", ...) {
+install_github <- function(repo, username = getOption("github.user"), branch = "master", subdir = NULL, ...) {
   message("Installing github repo(s) ", 
     paste(repo, branch, sep = "/", collapse = ", "), 
     " from ", 
@@ -23,5 +24,5 @@ install_github <- function(repo, username = "hadley", branch = "master", ...) {
   url <- paste("https://github.com/", username, "/", repo,
     "/zipball/", branch, sep = "")
 
-  install_url(url, paste(repo, ".zip", sep = ""), ...)
+  install_url(url, paste(repo, ".zip", sep = ""), subdir = subdir, ...)
 }
