@@ -20,7 +20,7 @@ load_data <- function(pkg = NULL, env = pkg_env(pkg)) {
   
   path_data <- file.path(pkg$path, "data")
   if (file.exists(path_data)) {
-    paths <- dir(path_data, "\\.[rR]da(ta)?$", full.names = TRUE)
+    paths <- dir(path_data, "\\.[rR][dD]a(ta)?$", full.names = TRUE)
     paths <- changed_files(paths)
     objs <- c(objs, unlist(lapply(paths, load, envir = env)))
     
